==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/GridColumnFilterOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
import { GridColumnFilterOptionsDescription } from "./GridColumnFilterOptionsDescription";
/**
 * @hidden
 */
var GridColumnFilterOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnFilterOptionsDescriptionMetadata, _super);
    function GridColumnFilterOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnFilterOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnFilterOptionsDescriptionMetadata.a == null) {
            GridColumnFilterOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnFilterOptionsDescriptionMetadata.c(GridColumnFilterOptionsDescriptionMetadata.a);
        }
        if (a.j(GridColumnFilterOptionsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridColumnFilterOptionsDescriptionMetadata.a);
    };
    GridColumnFilterOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
        a.item("ClearColumnFiltersCaption", "String");
        a.item("FilterListPlaceholderText", "String");
        a.item("FilterListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("FilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualFilterListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualFilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("TextFilterCaption", "String");
    };
    GridColumnFilterOptionsDescriptionMetadata.d = function (a) {
        GridColumnFilterOptionsDescriptionMetadata.b(a);
        a.aa("GridColumnFilterOptions", function () { return new GridColumnFilterOptionsDescription(); });
        a.z("GridColumnFilterOptions", GridColumnFilterOptionsDescriptionMetadata.a);
    };
    GridColumnFilterOptionsDescriptionMetadata.$t = markType(GridColumnFilterOptionsDescriptionMetadata, 'GridColumnFilterOptionsDescriptionMetadata');
    GridColumnFilterOptionsDescriptionMetadata.a = null;
    return GridColumnFilterOptionsDescriptionMetadata;
}(Base));
export { GridColumnFilterOptionsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GridColumnFilterOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
import { GridColumnFilterOptionsDescription } from "./GridColumnFilterOptionsDescription";
/**
 * @hidden
 */
var GridColumnFilterOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnFilterOptionsDescriptionMetadata, _super);
    function GridColumnFilterOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnFilterOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnFilterOptionsDescriptionMetadata.a == null) {
            GridColumnFilterOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnFilterOptionsDescriptionMetadata.c(GridColumnFilterOptionsDescriptionMetadata.a);
        }
        if (a.k(GridColumnFilterOptionsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridColumnFilterOptionsDescriptionMetadata.a);
    };
    GridColumnFilterOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
        a.item("ClearColumnFiltersCaption", "String");
        a.item("FilterListPlaceholderText", "String");
        a.item("FilterListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("FilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualFilterListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualFilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("TextFilterCaption", "String");
    };
    GridColumnFilterOptionsDescriptionMetadata.d = function (a) {
        GridColumnFilterOptionsDescriptionMetadata.b(a);
        a.ac("GridColumnFilterOptions", function () { return new GridColumnFilterOptionsDescription(); });
        a.ab("GridColumnFilterOptions", GridColumnFilterOptionsDescriptionMetadata.a);
    };
    GridColumnFilterOptionsDescriptionMetadata.$t = markType(GridColumnFilterOptionsDescriptionMetadata, 'GridColumnFilterOptionsDescriptionMetadata');
    GridColumnFilterOptionsDescriptionMetadata.a = null;
    return GridColumnFilterOptionsDescriptionMetadata;
}(Base));
export { GridColumnFilterOptionsDescriptionMetadata };
